@@ -1,3 +1,4 @@
+import builtins
 import sys
 import time
 import types
@@ -111,11 +112,13 @@ class Executor(object):
             # execute
             "execute_action": self.execute_action,
             "execute_files": self.execute_files,
+            # Add package
             "add_package_to_executor": package_manager.add_package_to_executor,
+            "add_package_to_callback_executor": package_manager.add_package_to_callback_executor,
         }
-        # get all time module builtin function and add to event dict
-        for function in getmembers(time, isbuiltin):
-            self.event_dict.update({str(function): function})
+        # get all builtin function and add to event dict
+        for function in getmembers(builtins, isbuiltin):
+            self.event_dict.update({str(function[0]): function[1]})
 
     def _execute_event(self, action: list):
         """
@@ -124,7 +127,10 @@ class Executor(object):
         """
         event = self.event_dict.get(action[0])
         if len(action) == 2:
-            return event(**action[1])
+            if isinstance(action[1], dict):
+                return event(**action[1])
+            else:
+                return event(*action[1])
         elif len(action) == 1:
             return event()
         else:
@@ -181,6 +187,7 @@ class Executor(object):
 
 
 executor = Executor()
+package_manager.executor = executor
 
 
 def add_command_to_executor(command_dict: dict):
